EXPORTS
	??0TRPSOwnNumbers@@QAE@XZ @ 1 NONAME ; TRPSOwnNumbers::TRPSOwnNumbers(void)
	??1CRpsMsg@@UAE@XZ @ 2 NONAME ; CRpsMsg::~CRpsMsg(void)
	?ArraySize@CRpsMsg@@QBEHXZ @ 3 NONAME ; int CRpsMsg::ArraySize(void) const
	?ExternalizeL@CRpsMsg@@QAEXAAPAVHBufC8@@@Z @ 4 NONAME ; void CRpsMsg::ExternalizeL(class HBufC8 * &)
	?GetArgL@CRpsMsg@@QAE?AVTPtrC8@@H@Z @ 5 NONAME ; class TPtrC8 CRpsMsg::GetArgL(int)
	?GetMsgNum@CRpsMsg@@QBEHXZ @ 6 NONAME ; int CRpsMsg::GetMsgNum(void) const
	?GetMsgType@CRpsMsg@@QBE?AVTPtrC8@@XZ @ 7 NONAME ; class TPtrC8 CRpsMsg::GetMsgType(void) const
	?GetOpCode@CRpsMsg@@QBE?AVTPtrC8@@XZ @ 8 NONAME ; class TPtrC8 CRpsMsg::GetOpCode(void) const
	?GetRawDataL@CRpsMsg@@QAE?AVTPtrC8@@H@Z @ 9 NONAME ; class TPtrC8 CRpsMsg::GetRawDataL(int)
	?InternalizeL@CRpsMsg@@QAEHABVTDesC8@@@Z @ 10 NONAME ; int CRpsMsg::InternalizeL(class TDesC8 const &)
	?NewL@CRpsMsg@@SAPAV1@ABVTDesC8@@0IABVCDesC16ArrayFlat@@@Z @ 11 NONAME ; class CRpsMsg * CRpsMsg::NewL(class TDesC8 const &, class TDesC8 const &, unsigned int, class CDesC16ArrayFlat const &)
	?NewL@CRpsMsg@@SAPAV1@XZ @ 12 NONAME ; class CRpsMsg * CRpsMsg::NewL(void)
	?NewLC@CRpsMsg@@SAPAV1@ABVTDesC8@@0IABVCDesC16ArrayFlat@@@Z @ 13 NONAME ; class CRpsMsg * CRpsMsg::NewLC(class TDesC8 const &, class TDesC8 const &, unsigned int, class CDesC16ArrayFlat const &)
	?NewLC@CRpsMsg@@SAPAV1@XZ @ 14 NONAME ; class CRpsMsg * CRpsMsg::NewLC(void)
	?RetrieveOwnNumbersL@TRPSOwnNumbers@@QAEHAAVRMobilePhone@@@Z @ 15 NONAME ; int TRPSOwnNumbers::RetrieveOwnNumbersL(class RMobilePhone &)

